==> jc-1.4.0.tar.gz: gnu/java/beans/DummyAppletStub.h <==
// public class gnu.java.beans.DummyAppletStub

// class file dependencies
// @dep_class b38540e39f7eec2c gnu_java_beans_DummyAppletStub
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_DummyAppletStub_H_
#define _JC_gnu_java_beans_DummyAppletStub_H_

// Forward structure declarations
struct _jc_gnu_java_beans_DummyAppletContext$object;
struct _jc_java_applet_AppletContext$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;

// Typedefs
typedef struct _jc_gnu_java_beans_DummyAppletStub$sub_refs	_jc_gnu_java_beans_DummyAppletStub$sub_refs;
typedef struct _jc_gnu_java_beans_DummyAppletStub$sub_nonrefs	_jc_gnu_java_beans_DummyAppletStub$sub_nonrefs;
typedef struct _jc_gnu_java_beans_DummyAppletStub$refs	_jc_gnu_java_beans_DummyAppletStub$refs;
typedef struct _jc_gnu_java_beans_DummyAppletStub$nonrefs	_jc_gnu_java_beans_DummyAppletStub$nonrefs;
typedef struct _jc_gnu_java_beans_DummyAppletStub$object	_jc_gnu_java_beans_DummyAppletStub$object;

typedef const struct _jc_gnu_java_beans_DummyAppletStub$vmethods	_jc_gnu_java_beans_DummyAppletStub$vmethods;
typedef const struct _jc_gnu_java_beans_DummyAppletStub$vtable	_jc_gnu_java_beans_DummyAppletStub$vtable;
typedef const struct _jc_gnu_java_beans_DummyAppletStub$vtype	_jc_gnu_java_beans_DummyAppletStub$vtype;

// Constructors
extern void _jc_gnu_java_beans_DummyAppletStub$method$_init$280cb3209579ae8a(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *, struct _jc_java_net_URL$object *, struct _jc_java_net_URL$object *);

// Virtual methods
extern void _jc_gnu_java_beans_DummyAppletStub$method$appletResize$1841bf52b0dd8fee(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *, jint, jint);
extern struct _jc_object *_jc_gnu_java_beans_DummyAppletStub$method$getAppletContext$e428f59baa0e46e5(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *);
extern struct _jc_java_net_URL$object *_jc_gnu_java_beans_DummyAppletStub$method$getCodeBase$6303bbff3a4f0712(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *);
extern struct _jc_java_net_URL$object *_jc_gnu_java_beans_DummyAppletStub$method$getDocumentBase$0e78e7be5575e4cb(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_beans_DummyAppletStub$method$getParameter$26c30f327708b7fe(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *, struct _jc_java_lang_String$object *);
extern jboolean _jc_gnu_java_beans_DummyAppletStub$method$isActive$569aa1fe3a4fd88d(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_DummyAppletStub$method_info$appletResize$1841bf52b0dd8fee;
extern _jc_method _jc_gnu_java_beans_DummyAppletStub$method_info$getAppletContext$e428f59baa0e46e5;
extern _jc_method _jc_gnu_java_beans_DummyAppletStub$method_info$getCodeBase$6303bbff3a4f0712;
extern _jc_method _jc_gnu_java_beans_DummyAppletStub$method_info$getDocumentBase$0e78e7be5575e4cb;
extern _jc_method _jc_gnu_java_beans_DummyAppletStub$method_info$getParameter$26c30f327708b7fe;
extern _jc_method _jc_gnu_java_beans_DummyAppletStub$method_info$isActive$569aa1fe3a4fd88d;

// Virtual methods structure
struct _jc_gnu_java_beans_DummyAppletStub$vmethods {
	void	(*appletResize$1841bf52b0dd8fee)(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *, jint, jint);
	struct _jc_object	*(*getAppletContext$e428f59baa0e46e5)(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *);
	struct _jc_java_net_URL$object	*(*getCodeBase$6303bbff3a4f0712)(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *);
	struct _jc_java_net_URL$object	*(*getDocumentBase$0e78e7be5575e4cb)(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *);
	struct _jc_java_lang_String$object	*(*getParameter$26c30f327708b7fe)(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *, struct _jc_java_lang_String$object *);
	jboolean	(*isActive$569aa1fe3a4fd88d)(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *);
};

// Vtable
struct _jc_gnu_java_beans_DummyAppletStub$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_DummyAppletStub$vmethods	gnu_java_beans_DummyAppletStub;
};

// Vtype
struct _jc_gnu_java_beans_DummyAppletStub$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_DummyAppletStub$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_DummyAppletStub$sub_refs {
	struct _jc_java_net_URL$object	*documentBase;
	struct _jc_java_net_URL$object	*codeBase;
	struct _jc_gnu_java_beans_DummyAppletContext$object	*context;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_DummyAppletStub$refs {
    _jc_gnu_java_beans_DummyAppletStub$sub_refs	gnu_java_beans_DummyAppletStub;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_DummyAppletStub$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_DummyAppletStub$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_DummyAppletStub$sub_nonrefs	gnu_java_beans_DummyAppletStub;
};

// Object instance structure
struct _jc_gnu_java_beans_DummyAppletStub$object {
	_jc_gnu_java_beans_DummyAppletStub$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_DummyAppletStub$vtype	*vtype;
	_jc_gnu_java_beans_DummyAppletStub$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_DummyAppletStub$vtype _jc_gnu_java_beans_DummyAppletStub$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_DummyAppletStub, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_DummyAppletStub$class_object;

#endif	/* _JC_gnu_java_beans_DummyAppletStub_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/DummyAppletStub.h <==
// public class gnu.java.beans.DummyAppletStub

// class file dependencies
// @dep_class b38540e39f7eec2c gnu_java_beans_DummyAppletStub
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_DummyAppletStub_H_
#define _JC_gnu_java_beans_DummyAppletStub_H_

// Forward structure declarations
struct _jc_gnu_java_beans_DummyAppletContext$object;
struct _jc_java_applet_AppletContext$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;

// Typedefs
typedef struct _jc_gnu_java_beans_DummyAppletStub$sub_refs	_jc_gnu_java_beans_DummyAppletStub$sub_refs;
typedef struct _jc_gnu_java_beans_DummyAppletStub$sub_nonrefs	_jc_gnu_java_beans_DummyAppletStub$sub_nonrefs;
typedef struct _jc_gnu_java_beans_DummyAppletStub$refs	_jc_gnu_java_beans_DummyAppletStub$refs;
typedef struct _jc_gnu_java_beans_DummyAppletStub$nonrefs	_jc_gnu_java_beans_DummyAppletStub$nonrefs;
typedef struct _jc_gnu_java_beans_DummyAppletStub$object	_jc_gnu_java_beans_DummyAppletStub$object;

typedef const struct _jc_gnu_java_beans_DummyAppletStub$vmethods	_jc_gnu_java_beans_DummyAppletStub$vmethods;
typedef const struct _jc_gnu_java_beans_DummyAppletStub$vtable	_jc_gnu_java_beans_DummyAppletStub$vtable;
typedef const struct _jc_gnu_java_beans_DummyAppletStub$vtype	_jc_gnu_java_beans_DummyAppletStub$vtype;

// Constructors
extern void _jc_gnu_java_beans_DummyAppletStub$method$_init$280cb3209579ae8a(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *, struct _jc_java_net_URL$object *, struct _jc_java_net_URL$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_beans_DummyAppletStub$method$appletResize$1841bf52b0dd8fee(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_beans_DummyAppletStub$method$getAppletContext$e428f59baa0e46e5(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *) _JC_JCNI_ATTR;
extern struct _jc_java_net_URL$object *_jc_gnu_java_beans_DummyAppletStub$method$getCodeBase$6303bbff3a4f0712(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *) _JC_JCNI_ATTR;
extern struct _jc_java_net_URL$object *_jc_gnu_java_beans_DummyAppletStub$method$getDocumentBase$0e78e7be5575e4cb(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_beans_DummyAppletStub$method$getParameter$26c30f327708b7fe(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_beans_DummyAppletStub$method$isActive$569aa1fe3a4fd88d(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_DummyAppletStub$method_info$appletResize$1841bf52b0dd8fee;
extern _jc_method _jc_gnu_java_beans_DummyAppletStub$method_info$getAppletContext$e428f59baa0e46e5;
extern _jc_method _jc_gnu_java_beans_DummyAppletStub$method_info$getCodeBase$6303bbff3a4f0712;
extern _jc_method _jc_gnu_java_beans_DummyAppletStub$method_info$getDocumentBase$0e78e7be5575e4cb;
extern _jc_method _jc_gnu_java_beans_DummyAppletStub$method_info$getParameter$26c30f327708b7fe;
extern _jc_method _jc_gnu_java_beans_DummyAppletStub$method_info$isActive$569aa1fe3a4fd88d;

// Virtual methods structure
struct _jc_gnu_java_beans_DummyAppletStub$vmethods {
	void	(*appletResize$1841bf52b0dd8fee)(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *, jint, jint) _JC_JCNI_ATTR;
	struct _jc_object	*(*getAppletContext$e428f59baa0e46e5)(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *) _JC_JCNI_ATTR;
	struct _jc_java_net_URL$object	*(*getCodeBase$6303bbff3a4f0712)(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *) _JC_JCNI_ATTR;
	struct _jc_java_net_URL$object	*(*getDocumentBase$0e78e7be5575e4cb)(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getParameter$26c30f327708b7fe)(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	jboolean	(*isActive$569aa1fe3a4fd88d)(_jc_env *, struct _jc_gnu_java_beans_DummyAppletStub$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_DummyAppletStub$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_DummyAppletStub$vmethods	gnu_java_beans_DummyAppletStub;
};

// Vtype
struct _jc_gnu_java_beans_DummyAppletStub$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_DummyAppletStub$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_DummyAppletStub$sub_refs {
	struct _jc_java_net_URL$object	*documentBase;
	struct _jc_java_net_URL$object	*codeBase;
	struct _jc_gnu_java_beans_DummyAppletContext$object	*context;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_DummyAppletStub$refs {
    _jc_gnu_java_beans_DummyAppletStub$sub_refs	gnu_java_beans_DummyAppletStub;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_DummyAppletStub$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_DummyAppletStub$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_DummyAppletStub$sub_nonrefs	gnu_java_beans_DummyAppletStub;
};

// Object instance structure
struct _jc_gnu_java_beans_DummyAppletStub$object {
	_jc_gnu_java_beans_DummyAppletStub$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_DummyAppletStub$vtype	*vtype;
	_jc_gnu_java_beans_DummyAppletStub$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_DummyAppletStub$vtype _jc_gnu_java_beans_DummyAppletStub$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_DummyAppletStub, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_DummyAppletStub$class_object;

#endif	/* _JC_gnu_java_beans_DummyAppletStub_H_ */
